@@ -27,7 +27,7 @@ def check_config(path) -> Config:
     """
     if path.is_file():
         try:
-            return Config.from_dict(json.loads(CONFIG_PATH.read_text('utf-8')))
+            return Config.from_dict(json.loads(path.read_text('utf-8')))
         except KeyError:
             return create_config()
 
@@ -308,7 +308,7 @@ def create_parser() -> argparse.ArgumentParser:
     parser.add_argument('-C', '--config-file', dest='config_file', default=CONFIG_PATH, help=f'Use another config file')
     parser.add_argument('-p', '--preset', help=f'Use preset', choices=list(PRESETS.keys()))
     parser.add_argument('-m', '--mode', help=f'Color mode', choices=['8bit', 'rgb'])
-    parser.add_argument('-b', '--backend', help=f'Choose a *fetch backend', choices=['neofetch', 'fastfetch', 'fastfetch-old'])
+    parser.add_argument('-b', '--backend', help=f'Choose a *fetch backend', choices=['qwqfetch', 'neofetch', 'fastfetch', 'fastfetch-old'])
     parser.add_argument('--args', help=f'Additional arguments pass-through to backend')
     parser.add_argument('--c-scale', dest='scale', help=f'Lighten colors by a multiplier', type=float)
     parser.add_argument('--c-set-l', dest='light', help=f'Set lightness value of the colors', type=float)
@@ -376,17 +376,20 @@ def run():
 
     # Check if it's June (pride month)
     now = datetime.datetime.now()
-    if now.month == 6 and now.year not in config.pride_month_shown and os.isatty(sys.stdout.fileno()):
+    june_path = CACHE_PATH / f'animation-displayed-{now.year}'
+    if now.month == 6 and now.year not in config.pride_month_shown and not june_path.is_file() and os.isatty(sys.stdout.fileno()):
         args.june = True
 
-    if args.june:
+    if args.june and not config.pride_month_disable:
         pride_month.start_animation()
         print()
         print("Happy pride month!")
         print("(You can always view the animation again with `hyfetch --june`)")
         print()
-        config.pride_month_shown.append(now.year)
-        config.save()
+
+        if not june_path.is_file():
+            june_path.parent.mkdir(parents=True, exist_ok=True)
+            june_path.touch()
 
     # Use a custom distro
     GLOBAL_CFG.override_distro = args.distro or config.distro
@@ -398,6 +401,8 @@ def run():
         config.mode = args.mode
     if args.backend:
         config.backend = args.backend
+    if args.args:
+        config.args = args.args
 
     # Override global color mode
     GLOBAL_CFG.color_mode = config.mode
@@ -418,7 +423,7 @@ def run():
     try:
         asc = get_distro_ascii() if not args.ascii_file else Path(args.ascii_file).read_text("utf-8")
         asc = config.color_align.recolor_ascii(asc, preset)
-        neofetch_util.run(asc, config.backend, args.args or '')
+        neofetch_util.run(asc, config.backend, config.args or '')
     except Exception as e:
         print(f'Error: {e}')
         traceback.print_exc()
